<?php

namespace App\Controller;

use App\Container;
use App\Router\Request\IRequest;
use App\Router\Response\RedirectResponse;
use App\Router\Response\Response;
use App\Router\Response\IResponse;

use App\Router\Session;
use DateTime;
use Manager\UserManager;
use Shared\Attributes\Route;
use Shared\Validation;
use Twig\Environment;
use Data\Core\Preferences;
use Shared\Log;
use function PHPUnit\Framework\isEmpty;
use Database\Athletegateway;
use Database\Connexion;

class UserController extends BaseController
{

    private UserManager $userMgr;
    public function __construct(UserManager $manager){
        parent::__construct();
        $this->userMgr =  $manager;
    }

    #[Route(path: '/', name: 'index', methods: ['GET'])]
    public function index(): Response
    {
        return $this->render('./page/index.html',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

    #[Route(path: '/home', name: 'home', methods: ['GET'])]
    public function home(): Response
    {
        $athleteGateway = new AthleteGateway(new Connexion(DSN, DB_USER, DB_PASSWORD));
        $activity = $athleteGateway->getListActivity('1');//$currentUser->getId()

        $charts = [];
        $i = 0;
        while ($i <= 12) {
            if ($activity[$i]['mois'] == null) {
                $activity[$i]['mois'] = $i;
                $activity[$i]['nbactivite'] = 0;
            } elseif (($indice = intval($activity[$i]['mois'])) != $i) {
                $temp = $activity[$i]; // Stocker temporairement les données actuelles
                $activity[$i]['mois'] = $i;
                $activity[$i]['nbactivite'] = 0;
                $activity[$indice]['mois'] = $indice;
                $activity[$indice]['nbactivite'] = $temp['nbactivite']; // Restaurer les données
            }
            $charts[] = ['act' => $activity[$i]['nbactivite'], 'mois' => $activity[$i]['mois']];
            $i++;
        }

        return $this->render('./page/home.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'charts' => $charts,
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }


    #[Route(path: '/settings', name: 'settings', methods: ['GET'])]
    public function settings(IRequest $req): Response
    {
        return $this->render('./page/settings.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

    #[Route(path: '/profile', name: 'profile', methods: ['GET'])]
    public function profile(): Response
    {
        return $this->render('./page/profile.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

    #[Route(path: '/preferences', name: 'preferences', methods: ['POST'])]
    public function preferences(string $theme, IRequest $req): Response
    {
        /*TODO*/

        //  VALIDER LES DONNEES
        $this->preference->majCookie($theme);
       
        return $this->render('./page/settings.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

//    #[Route(path: '/logout', name: 'logout', methods: ['GET'])]
//    public function logout(IRequest $request): IResponse
//    {
//        $error = [];
//
//        try {
//
//            if($this->userMgr->deconnecter()){
//                return new RedirectResponse('/');
//            }
//            else{
//                $error [] = "Erreur de deconnexion. Essayez encore";
//                return new RedirectResponse('/');
//            }
//
//        } catch (\Throwable $th) {
//            $error [] =$th->getMessage();
//            return new RedirectResponse('/');
//        }
//    }
    
}